==> juce-docs-7.0.8-1-aarch64.pkg.tar.xz: usr/share/doc/juce/html/search/all_11.js <==
var searchData=
[
  ['quadraphonic_0',['quadraphonic',['../classAudioChannelSet.html#ab216c3d458cbd3965e321a29d12d591d',1,'AudioChannelSet']]],
  ['quadraticto_1',['quadraticto',['../classRelativePointPath_1_1QuadraticTo.html',1,'RelativePointPath::QuadraticTo'],['../classRelativePointPath_1_1QuadraticTo.html#aba89135707082499521af4acc13d8182',1,'RelativePointPath::QuadraticTo::QuadraticTo()'],['../classPath_1_1Iterator.html#a62b1a329e3fdbcbdad78bb6c90c7bcfda3a092657aa2dec64c33926a6528c9f9b',1,'Path::Iterator::quadraticTo'],['../classPath.html#ab50510cf385b9ea3fe64fef6be45f85b',1,'Path::quadraticTo(float controlPointX, float controlPointY, float endPointX, float endPointY)'],['../classPath.html#afc8df505c72587a7c973ec20e28e418c',1,'Path::quadraticTo(Point&lt; float &gt; controlPoint, Point&lt; float &gt; endPoint)']]],
  ['quadratictoelement_2',['quadraticToElement',['../classRelativePointPath.html#a741fbc9bca4a156a84514f20987483e9a8494c007547e881252ae413d840908ca',1,'RelativePointPath']]],
  ['quarterframe_3',['quarterFrame',['../classMidiMessage.html#ab21def5ca28557f4d7df31c8425c3386',1,'MidiMessage']]],
  ['quaternion_4',['quaternion',['../classQuaternion.html',1,'Quaternion&lt; Type &gt;'],['../classQuaternion.html#a1b5dab7556226d76040277dc8ee3f0a4',1,'Quaternion::Quaternion(Type x, Type y, Type z, Type w) noexcept'],['../classQuaternion.html#a80054cbe7779c1237c1d08f53077bd43',1,'Quaternion::Quaternion(Vector3D&lt; Type &gt; vectorPart, Type scalarPart) noexcept'],['../classQuaternion.html#a55df57ee8430a9b1b1581ace70e105e3',1,'Quaternion::Quaternion(const Quaternion &amp;other) noexcept'],['../classQuaternion.html#ab6cfa17954ad0cf303877c8b7d578cc2',1,'Quaternion::Quaternion() noexcept']]],
  ['quaternion_3c_20float_20_3e_5',['Quaternion&lt; float &gt;',['../classQuaternion.html',1,'']]],
  ['quaterniontype_6',['QuaternionType',['../classDraggable3DOrientation.html#aac3238fcd660a2c81628e0ae2e4ba717',1,'Draggable3DOrientation']]],
  ['queryiaudioprocessor_7',['queryIAudioProcessor',['../structVST3ClientExtensions.html#a59c5142f3d0b7d2a8d227cd1d3fb0f0b',1,'VST3ClientExtensions']]],
  ['queryieditcontroller_8',['queryIEditController',['../structVST3ClientExtensions.html#accda7661d727659ea6fe61e6e02030f0',1,'VST3ClientExtensions']]],
  ['queryinterface_9',['queryInterface',['../classActiveXControlComponent.html#ad79a5c7bebaffb582120d402f48219c1',1,'ActiveXControlComponent']]],
  ['questionicon_10',['questionicon',['../classAlertWindow.html#a5ed05bbd4a32421dcac8aa50ca9b0065',1,'AlertWindow::QuestionIcon'],['../group__juce__gui__basics-windows.html#gga82b3ccfe63090a7818d1028e04b44bd0a49bd215cebe9a92fbb9ab5af2c9a617c',1,'QuestionIcon:&#160;juce_MessageBoxOptions.h']]],
  ['quit_11',['quit',['../classJUCEApplicationBase.html#a542e212605f0aa693f687d8798998615',1,'JUCEApplicationBase::quit()'],['../namespaceStandardApplicationCommandIDs.html#ad348cc9beaaea88093769e2da468320aa0e06bba45d6039ddc74f0b437d982fba',1,'StandardApplicationCommandIDs::quit']]],
  ['quoted_12',['quoted',['../classString.html#a59db7c96e9b9e6cfb39754c43c758026',1,'String']]]
];

==> juce-docs-7.0.9-1-aarch64.pkg.tar.xz: usr/share/doc/juce/html/search/all_11.js <==
var searchData=
[
  ['quadraphonic_0',['quadraphonic',['../classAudioChannelSet.html#ab216c3d458cbd3965e321a29d12d591d',1,'AudioChannelSet']]],
  ['quadraticto_1',['quadraticto',['../classRelativePointPath_1_1QuadraticTo.html',1,'RelativePointPath::QuadraticTo'],['../classPath_1_1Iterator.html#a62b1a329e3fdbcbdad78bb6c90c7bcfda3a092657aa2dec64c33926a6528c9f9b',1,'Path::Iterator::quadraticTo'],['../classPath.html#ab50510cf385b9ea3fe64fef6be45f85b',1,'Path::quadraticTo(float controlPointX, float controlPointY, float endPointX, float endPointY)'],['../classPath.html#afc8df505c72587a7c973ec20e28e418c',1,'Path::quadraticTo(Point&lt; float &gt; controlPoint, Point&lt; float &gt; endPoint)'],['../classRelativePointPath_1_1QuadraticTo.html#aba89135707082499521af4acc13d8182',1,'RelativePointPath::QuadraticTo::QuadraticTo()']]],
  ['quadratictoelement_2',['quadraticToElement',['../classRelativePointPath.html#a741fbc9bca4a156a84514f20987483e9a8494c007547e881252ae413d840908ca',1,'RelativePointPath']]],
  ['quarterframe_3',['quarterFrame',['../classMidiMessage.html#ab21def5ca28557f4d7df31c8425c3386',1,'MidiMessage']]],
  ['quaternion_4',['quaternion',['../classQuaternion.html',1,'Quaternion&lt; Type &gt;'],['../classQuaternion.html#a1b5dab7556226d76040277dc8ee3f0a4',1,'Quaternion::Quaternion(Type x, Type y, Type z, Type w) noexcept'],['../classQuaternion.html#a80054cbe7779c1237c1d08f53077bd43',1,'Quaternion::Quaternion(Vector3D&lt; Type &gt; vectorPart, Type scalarPart) noexcept'],['../classQuaternion.html#a55df57ee8430a9b1b1581ace70e105e3',1,'Quaternion::Quaternion(const Quaternion &amp;other) noexcept'],['../classQuaternion.html#ab6cfa17954ad0cf303877c8b7d578cc2',1,'Quaternion::Quaternion() noexcept']]],
  ['quaternion_3c_20float_20_3e_5',['Quaternion&lt; float &gt;',['../classQuaternion.html',1,'']]],
  ['quaterniontype_6',['QuaternionType',['../classDraggable3DOrientation.html#aac3238fcd660a2c81628e0ae2e4ba717',1,'Draggable3DOrientation']]],
  ['queryiaudioprocessor_7',['queryIAudioProcessor',['../structVST3ClientExtensions.html#a59c5142f3d0b7d2a8d227cd1d3fb0f0b',1,'VST3ClientExtensions']]],
  ['queryieditcontroller_8',['queryIEditController',['../structVST3ClientExtensions.html#accda7661d727659ea6fe61e6e02030f0',1,'VST3ClientExtensions']]],
  ['queryinterface_9',['queryInterface',['../classActiveXControlComponent.html#ad79a5c7bebaffb582120d402f48219c1',1,'ActiveXControlComponent']]],
  ['questionicon_10',['questionicon',['../classAlertWindow.html#a5ed05bbd4a32421dcac8aa50ca9b0065',1,'AlertWindow::QuestionIcon'],['../group__juce__gui__basics-windows.html#gga82b3ccfe63090a7818d1028e04b44bd0a49bd215cebe9a92fbb9ab5af2c9a617c',1,'QuestionIcon:&#160;juce_MessageBoxOptions.h']]],
  ['quit_11',['quit',['../classJUCEApplicationBase.html#a542e212605f0aa693f687d8798998615',1,'JUCEApplicationBase::quit()'],['../namespaceStandardApplicationCommandIDs.html#ad348cc9beaaea88093769e2da468320aa0e06bba45d6039ddc74f0b437d982fba',1,'StandardApplicationCommandIDs::quit']]],
  ['quoted_12',['quoted',['../classString.html#a59db7c96e9b9e6cfb39754c43c758026',1,'String']]]
];
